# Machine Intelligence

## Compression

Surprisingly, many researchers in Machine Intelligence spend a lot of time creating new and better compression algorithms. Why would this be?

How is Machine Learning like ...

- Communication (transmitting information)
- Visualization (conveying knowledge to a human)

Later in this course you'll learn why. Once you've mastered the basics and can perform regression and classification several different ways, we'll talk about information theory, channel capacity, complexity, entropy, and intelligence metrics.

